@@ -72,18 +72,25 @@ class PackageConfig
 
     def guess_native_pkg_config
       exeext = RbConfig::CONFIG["EXEEXT"]
-      default_pkg_config = ENV["PKG_CONFIG"] || "pkg-config#{exeext}"
-      pkg_config = with_config("pkg-config", default_pkg_config)
-      pkg_config = Pathname.new(pkg_config)
-      unless pkg_config.absolute?
-        found_pkg_config = search_executable_from_path(pkg_config)
-        pkg_config = found_pkg_config if found_pkg_config
+      candidates = [
+        with_config("pkg-config"),
+        ENV["PKG_CONFIG"],
+        "pkgconf#{exeext}",
+        "pkg-config#{exeext}",
+      ].compact
+      candidates.each do |pkg_config|
+        pkg_config = Pathname.new(pkg_config)
+        return pkg_config if pkg_config.absolute? and pkg_config.exist?
+        unless pkg_config.absolute?
+          found_pkg_config = search_executable_from_path(pkg_config)
+          return found_pkg_config if found_pkg_config
+        end
+        unless pkg_config.absolute?
+          found_pkg_config = search_pkg_config_by_dln_find_exe(pkg_config)
+          return found_pkg_config if found_pkg_config
+        end
       end
-      unless pkg_config.absolute?
-        found_pkg_config = search_pkg_config_by_dln_find_exe(pkg_config)
-        pkg_config = found_pkg_config if found_pkg_config
-      end
-      pkg_config
+      Pathname.new(candidates[0])
     end
 
     def search_executable_from_path(name)
@@ -173,6 +180,7 @@ class PackageConfig
         conda_prefix = ENV["CONDA_PREFIX"]
         if conda_prefix
           default_paths << File.join(conda_prefix, "lib", "pkgconfig")
+          default_paths << File.join(conda_prefix, "share", "pkgconfig")
         end
         default_paths << "/usr/local/lib64/pkgconfig"
         default_paths << "/usr/local/libx32/pkgconfig"
@@ -437,10 +445,10 @@ class PackageConfig
     begin
       loop do
         cflag = enumerator.next
-        normalized_cflags << cflag
+        normalized_cflags << cflag.dup
         case cflag
         when "-I"
-          normalized_cflags << enumerator.next
+          normalized_cflags.last << enumerator.next
         end
       end
     rescue StopIteration
@@ -506,6 +514,9 @@ class PackageConfig
     @declarations = {}
     File.open(pc_path) do |input|
       input.each_line do |line|
+        if line.dup.force_encoding("UTF-8").valid_encoding?
+          line.force_encoding("UTF-8")
+        end
         line = line.gsub(/#.*/, "").strip
         next if line.empty?
         case line
@@ -645,7 +656,7 @@ module PKGConfig
         "yes (#{modversion(pkg)})"
       else
         if exist?(pkg)
-          "no (#{modversion(pkg)}"
+          "no (#{modversion(pkg)})"
         else
           "no (nonexistent)"
         end
